==> arduino-esp8266-2.6.3.tgz: share/arduino/hardware/espressif/esp8266/cores/esp8266/Client.h <==
/*
 Client.h - Base class that provides Client
 Copyright (c) 2011 Adrian McEwen.  All right reserved.

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef client_h
#define client_h
#include "Print.h"
#include "Stream.h"
#include "IPAddress.h"

class Client: public Stream {

    public:
        virtual int connect(IPAddress ip, uint16_t port) =0;
        virtual int connect(const char *host, uint16_t port) =0;
        virtual size_t write(uint8_t) =0;
        virtual size_t write(const uint8_t *buf, size_t size) =0;
        virtual int available() = 0;
        virtual int read() = 0;
        virtual int read(uint8_t *buf, size_t size) = 0;
        virtual int peek() = 0;
        virtual void flush() = 0;
        virtual void stop() = 0;
        virtual uint8_t connected() = 0;
        virtual operator bool() = 0;
    protected:
        uint8_t* rawIPAddress(IPAddress& addr) {
            return addr.raw_address();
        }
#if LWIP_VERSION_MAJOR != 1
        const uint8_t* rawIPAddress(const IPAddress& addr) {
            return addr.raw_address();
        }
#endif
};

#endif

==> arduino-esp8266-3.0.2p4.tgz: share/arduino/hardware/espressif/esp8266/cores/esp8266/Client.h <==
/*
 Client.h - Base class that provides Client
 Copyright (c) 2011 Adrian McEwen.  All right reserved.

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef client_h
#define client_h
#include "Print.h"
#include "Stream.h"
#include "IPAddress.h"

class Client: public Stream {

    public:
        virtual int connect(IPAddress ip, uint16_t port) = 0;
        virtual int connect(const char *host, uint16_t port) = 0;
        virtual size_t write(uint8_t) override = 0;
        virtual size_t write(const uint8_t *buf, size_t size) override = 0;
        virtual int available() override = 0;
        virtual int read() override = 0;
        virtual int read(uint8_t *buf, size_t size) override = 0;
        virtual int peek() override = 0;
        virtual void flush() override = 0;
        virtual void stop() = 0;
        virtual uint8_t connected() = 0;
        virtual operator bool() = 0;
    protected:
        uint8_t* rawIPAddress(IPAddress& addr) {
            return addr.raw_address();
        }
        const uint8_t* rawIPAddress(const IPAddress& addr) {
            return addr.raw_address();
        }
};

#endif
